@@ -15,45 +15,49 @@
  *                                                                         *
  ***************************************************************************/
 
-// include files for Qt
-#include <qprinter.h>
-#include <qpainter.h>
-#include <qlayout.h>
-#include <qwhatsthis.h>
-#include <qpopupmenu.h>
-#include <qclipboard.h>
-
-// include files for KDE
-#include <klistbox.h>
-#include <klineedit.h>
-#include <kaudioplayer.h>
-#include <kcursor.h>
-#include <kiconloader.h>
-#include <klocale.h>
-#include <kfiledialog.h>
-#include <kcombobox.h>
-#include <kmessagebox.h>
-
-#include <stdlib.h>
-
 // application specific includes
-#include "phraselistitem.h"
 #include "phraselist.h"
+#include "phraselistitem.h"
 #include "phraseedit.h"
 #include "kmouth.h"
 #include "texttospeechsystem.h"
 #include "phrasebook/phrasebook.h"
 #include "wordcompletion/wordcompletion.h"
 
-PhraseList::PhraseList(QWidget *parent, const char *name) : QWidget(parent,name) {
+// include files for Qt
+#include <QtGui/QPainter>
+#include <QtGui/QLayout>
+#include <QtGui/QApplication>
+#include <QtGui/QMenu>
+#include <QtGui/QClipboard>
+#include <QtGui/QVBoxLayout>
+#include <QtGui/QHBoxLayout>
+#include <QtGui/QKeyEvent>
+
+// include files for KDE
+#include <klineedit.h>
+#include <kcursor.h>
+#include <kiconloader.h>
+#include <klocale.h>
+#include <kfiledialog.h>
+#include <kcombobox.h>
+#include <kmessagebox.h>
+#include <kxmlguifactory.h>
+
+#include <stdlib.h>
+
+
+PhraseList::PhraseList(QWidget *parent, const char *name) : QWidget(parent) {
+   Q_UNUSED(name);
    isInSlot = false;
-   setBackgroundMode(PaletteBase);
+   // FIXME: Remove or change PaletteBase to Qt::OpaqueMode?
+   // setBackgroundMode(PaletteBase);
    QVBoxLayout *layout = new QVBoxLayout (this);
 
-   listBox = new KListBox (this);
-   listBox->setFocusPolicy(QWidget::NoFocus);
-   listBox->setSelectionMode (QListBox::Extended);
-   QWhatsThis::add (listBox, i18n("This list contains the history of spoken sentences. You can select sentences and press the speak button for re-speaking."));
+   listBox = new K3ListBox (this);
+   listBox->setFocusPolicy(Qt::NoFocus);
+   listBox->setSelectionMode (Q3ListBox::Extended);
+   listBox->setWhatsThis( i18n("This list contains the history of spoken sentences. You can select sentences and press the speak button for re-speaking."));
    layout->addWidget(listBox);
 
    QHBoxLayout *rowLayout = new QHBoxLayout ();
@@ -61,31 +65,31 @@ PhraseList::PhraseList(QWidget *parent, const char *name) : QWidget(parent,name)
 
    completion = new WordCompletion();
 
-   dictionaryCombo = new KComboBox (this, "Dictionary Combo");
+   dictionaryCombo = new KComboBox (this);
    configureCompletionCombo(completion->wordLists());
    rowLayout->addWidget(dictionaryCombo);
 
    lineEdit = new PhraseEdit ("", this);
-   lineEdit->setFocusPolicy(QWidget::StrongFocus);
+   lineEdit->setFocusPolicy(Qt::StrongFocus);
    lineEdit->setFrame(true);
    lineEdit->setEchoMode(QLineEdit::Normal);
    lineEdit->setCompletionObject (completion);
    lineEdit->setAutoDeleteCompletionObject(true);
-   QWhatsThis::add (lineEdit, i18n("Into this edit field you can type a phrase. Click on the speak button in order to speak the entered phrase."));
+   lineEdit->setWhatsThis( i18n("Into this edit field you can type a phrase. Click on the speak button in order to speak the entered phrase."));
    rowLayout->addWidget(lineEdit);
    lineEdit->setFocus();
 
-   QIconSet icon = KGlobal::iconLoader()->loadIconSet("speak", KIcon::Small);
+   QIcon icon = KIconLoader::global()->loadIconSet("speak", KIconLoader::Small);
    speakButton = new QPushButton (icon, i18n("&Speak"), this);
-   speakButton->setFocusPolicy(QWidget::NoFocus);
+   speakButton->setFocusPolicy(Qt::NoFocus);
    speakButton->setAutoDefault(false);
-   QWhatsThis::add (speakButton, i18n("Speaks the currently active sentence(s). If there is some text in the edit field it is spoken. Otherwise the selected sentences in the history (if any) are spoken."));
+   speakButton->setWhatsThis( i18n("Speaks the currently active sentence(s). If there is some text in the edit field it is spoken. Otherwise the selected sentences in the history (if any) are spoken."));
    rowLayout->addWidget(speakButton);
 
    connect(dictionaryCombo, SIGNAL (activated (const QString &)), completion, SLOT (setWordList(const QString &)));
    connect(completion, SIGNAL (wordListsChanged (const QStringList &)), this, SLOT (configureCompletionCombo (const QStringList &)));
    connect(listBox,  SIGNAL(selectionChanged()), SLOT(selectionChanged()));
-   connect(listBox,  SIGNAL(contextMenuRequested (QListBoxItem *, const QPoint &)), SLOT(contextMenuRequested (QListBoxItem *, const QPoint &)));
+   connect(listBox,  SIGNAL(contextMenuRequested (Q3ListBoxItem *, const QPoint &)), SLOT(contextMenuRequested (Q3ListBoxItem *, const QPoint &)));
    connect(lineEdit, SIGNAL(returnPressed(const QString &)), SLOT(lineEntered(const QString &)));
    connect(lineEdit, SIGNAL(textChanged  (const QString &)), SLOT(textChanged(const QString &)));
    connect(speakButton, SIGNAL( clicked ()), SLOT(speak()));
@@ -97,9 +101,9 @@ PhraseList::~PhraseList() {
    delete lineEdit;
 }
 
-void PhraseList::print(KPrinter *pPrinter) {
+void PhraseList::print(QPrinter *pPrinter) {
    PhraseBook book;
-   for (QListBoxItem *item = listBox->firstItem(); item != 0; item = item->next()) {
+   for (Q3ListBoxItem *item = listBox->firstItem(); item != 0; item = item->next()) {
       book += PhraseBookEntry(Phrase(item->text()));
    }
    
@@ -109,7 +113,7 @@ void PhraseList::print(KPrinter *pPrinter) {
 QStringList PhraseList::getListSelection() {
    QStringList res = QStringList();
 
-   for (QListBoxItem *item = listBox->firstItem(); item != 0; item = item->next()) {
+   for (Q3ListBoxItem *item = listBox->firstItem(); item != 0; item = item->next()) {
       if (item->isSelected())
          res += item->text();
    }
@@ -118,7 +122,7 @@ QStringList PhraseList::getListSelection() {
 }
 
 bool PhraseList::existListSelection() {
-   for (QListBoxItem *item = listBox->firstItem(); item != 0; item = item->next()) {
+   for (Q3ListBoxItem *item = listBox->firstItem(); item != 0; item = item->next()) {
       if (item->isSelected())
          return true;
    }
@@ -133,7 +137,7 @@ bool PhraseList::existEditSelection() {
 void PhraseList::enableMenuEntries() {
    bool deselected = false;
    bool selected = false;
-   for (QListBoxItem *item = listBox->firstItem(); item != 0; item = item->next()) {
+   for (Q3ListBoxItem *item = listBox->firstItem(); item != 0; item = item->next()) {
       if (item->isSelected())
          selected = true;
       else
@@ -153,19 +157,19 @@ void PhraseList::configureCompletionCombo(const QStringList &list) {
    if (list.isEmpty())
       dictionaryCombo->hide();
    else if (list.count() == 1) {
-      dictionaryCombo->insertStringList (list);
-      dictionaryCombo->setCurrentItem (0);
+      dictionaryCombo->addItems (list);
+      dictionaryCombo->setCurrentIndex (0);
       dictionaryCombo->hide();
    }
    else {
-      dictionaryCombo->insertStringList (list);
+      dictionaryCombo->addItems (list);
       dictionaryCombo->show();
    
       QStringList::ConstIterator it;
       int i = 0;
       for (it = list.begin(), i = 0; it != list.end(); ++it, ++i) {
          if (current == *it) {
-            dictionaryCombo->setCurrentItem (i);
+            dictionaryCombo->setCurrentIndex (i);
             return;
          }
       }
@@ -173,31 +177,31 @@ void PhraseList::configureCompletionCombo(const QStringList &list) {
 }
 
 void PhraseList::saveCompletionOptions(KConfig *config) {
-   config->setGroup("General Options");
-   config->writeEntry("Show speak button", speakButton->isVisible() || !lineEdit->isVisible());
+   KConfigGroup cg(config,"General Options");
+   cg.writeEntry("Show speak button", speakButton->isVisible() || !lineEdit->isVisible());
       
-   config->setGroup("Completion");
-   config->writeEntry("Mode", static_cast<int>(lineEdit->completionMode()));
-   config->writeEntry("List", completion->currentWordList());
+   KConfigGroup cg2(config,"Completion");
+   cg2.writeEntry("Mode", static_cast<int>(lineEdit->completionMode()));
+   cg2.writeEntry("List", completion->currentWordList());
 }
 
 void PhraseList::readCompletionOptions(KConfig *config) {
-   config->setGroup("General Options");
-   if (!config->readBoolEntry("Show speak button", true))
+   KConfigGroup cg(config,"General Options");
+   if (!cg.readEntry("Show speak button", true))
       speakButton->hide();
 
    if (config->hasGroup ("Completion")) {
-      config->setGroup("Completion");
-      int mode = config->readNumEntry ("Mode", KGlobalSettings::completionMode());
+      KConfigGroup cg2(config, "Completion");
+      int mode = cg2.readEntry ("Mode", int(KGlobalSettings::completionMode()));
       lineEdit->setCompletionMode (static_cast<KGlobalSettings::Completion>(mode));
 
-      QString current = config->readEntry ("List", QString::null);
+      QString current = cg2.readEntry ("List", QString());
       QStringList list = completion->wordLists();
       QStringList::ConstIterator it;
       int i = 0;
       for (it = list.begin(), i = 0; it != list.end(); ++it, ++i) {
          if (current == *it) {
-            dictionaryCombo->setCurrentItem (i);
+            dictionaryCombo->setCurrentIndex (i);
             return;
          }
       }
@@ -254,8 +258,8 @@ void PhraseList::speakListSelection () {
 }
 
 void PhraseList::removeListSelection () {
-   QListBoxItem *next;
-   for (QListBoxItem *item = listBox->firstItem(); item != 0; item = next) {
+   Q3ListBoxItem *next;
+   for (Q3ListBoxItem *item = listBox->firstItem(); item != 0; item = next) {
       next = item->next();
       
       if (item->isSelected()) {
@@ -284,7 +288,8 @@ void PhraseList::lineEntered (const QString &phrase) {
 }
 
 void PhraseList::speakPhrase (const QString &phrase) {
-   QApplication::setOverrideCursor (KCursor::WaitCursor, false);
+   // QApplication::setOverrideCursor (KCursor::WaitCursor, false);
+   QApplication::setOverrideCursor (Qt::WaitCursor);
    KMouthApp *theApp=(KMouthApp *) parentWidget();
    QString language = completion->languageOfWordList (completion->currentWordList());
    theApp->getTTSSystem()->speak(phrase, language);
@@ -306,7 +311,7 @@ void PhraseList::insertIntoPhraseList (const QString &phrase, bool clearEditLine
    enableMenuEntries ();
 }
 
-void PhraseList::contextMenuRequested (QListBoxItem *, const QPoint &pos) {
+void PhraseList::contextMenuRequested (Q3ListBoxItem *, const QPoint &pos) {
    QString name;
    if (existListSelection())
       name = "phraselist_selection_popup";
@@ -315,9 +320,9 @@ void PhraseList::contextMenuRequested (QListBoxItem *, const QPoint &pos) {
    
    KMouthApp *theApp=(KMouthApp *) parentWidget();
    KXMLGUIFactory *factory = theApp->factory();
-   QPopupMenu *popup = (QPopupMenu *)factory->container(name,theApp);
+   QMenu *popup = (QMenu *)factory->container(name,theApp);
    if (popup != 0) {
-      popup->popup(pos, 0);
+      popup->exec(pos, 0);
    }
 }
 
@@ -359,7 +364,7 @@ void PhraseList::setEditLineText(const QString &s) {
 void PhraseList::keyPressEvent (QKeyEvent *e) {
    if (e->key() == Qt::Key_Up) {
       bool selected = false;
-      for (QListBoxItem *item = listBox->firstItem(); item != 0; item = item->next()) {
+      for (Q3ListBoxItem *item = listBox->firstItem(); item != 0; item = item->next()) {
          if (item->isSelected()) {
             selected = true;
          }
@@ -396,7 +401,7 @@ void PhraseList::keyPressEvent (QKeyEvent *e) {
    }
    else if (e->key() == Qt::Key_Down) {
       bool selected = false;
-      for (QListBoxItem *item = listBox->firstItem(); item != 0; item = item->next()) {
+      for (Q3ListBoxItem *item = listBox->firstItem(); item != 0; item = item->next()) {
          if (item->isSelected()) {
             selected = true;
          }
@@ -419,7 +424,7 @@ void PhraseList::keyPressEvent (QKeyEvent *e) {
       }
       e->accept();
    }
-   else if ((e->state() & Qt::KeyButtonMask) == Qt::ControlButton) {
+   else if (e->modifiers() & Qt::ControlModifier) {
       if (e->key() == Qt::Key_C) {
          copy();
          e->accept();
@@ -440,24 +445,24 @@ void PhraseList::save () {
    // format we use that method here.
    
    PhraseBook book;
-   for (QListBoxItem *item = listBox->firstItem(); item != 0; item = item->next()) {
+   for (Q3ListBoxItem *item = listBox->firstItem(); item != 0; item = item->next()) {
       book += PhraseBookEntry(Phrase(item->text()));
    }
 
-   KURL url;
+   KUrl url;
    if (book.save (this, i18n("Save As"), url, false) == -1)
-      KMessageBox::sorry(this,i18n("There was an error saving file\n%1").arg( url.url() ));
+      KMessageBox::sorry(this,i18n("There was an error saving file\n%1", url.url() ));
 }
 
 void PhraseList::open () {
-   KURL url=KFileDialog::getOpenURL(QString::null,
+   KUrl url=KFileDialog::getOpenUrl(KUrl(),
         i18n("*|All Files\n*.phrasebook|Phrase Books (*.phrasebook)\n*.txt|Plain Text Files (*.txt)"), this, i18n("Open File as History"));
 
    if(!url.isEmpty())
       open (url);
 }
 
-void PhraseList::open (KURL url) {
+void PhraseList::open (KUrl url) {
    // We want to open a history of spoken sentences here. However, as
    // the class PhraseBook does already provide a method for opening
    // both phrase books and plain text files we use that method here.
@@ -472,7 +477,7 @@ void PhraseList::open (KURL url) {
          insertIntoPhraseList (*it, false);
    }
    else
-      KMessageBox::sorry(this,i18n("There was an error loading file\n%1").arg( url.url() ));
+      KMessageBox::sorry(this,i18n("There was an error loading file\n%1", url.url() ));
 }
 
 #include "phraselist.moc"
