@@ -18,19 +18,18 @@
  ***************************************************************************/
 
 // Qt includes.
-#include <qmessagebox.h>
-#include <dcopclient.h>
-#include <qtimer.h>
+#include <QtGui/QMessageBox>
+#include <QtCore/QTimer>
+#include <QtDBus/QtDBus>
 
 // KDE includes.
 #include <ktexteditor/editinterface.h>
 #include <ktexteditor/selectioninterface.h>
-
 #include <kaction.h>
 #include <klocale.h>
 #include <kstandarddirs.h>
-#include <kapplication.h>
 #include <kgenericfactory.h>
+#include <ktoolinvocation.h>
 
 // KateKttsdPlugin includes.
 #include "katekttsd.h"
@@ -51,6 +50,7 @@ KateKttsdPlugin::~KateKttsdPlugin()
 void KateKttsdPlugin::addView(KTextEditor::View *view)
 {
     KateKttsdPluginView *nview = new KateKttsdPluginView (view, "KTTSD Plugin");
+    KGlobal::locale()->insertCatalog("kttsd");
     m_views.append (nview);
 }
 
@@ -63,7 +63,7 @@ void KateKttsdPlugin::removeView(KTextEditor::View *view)
         m_views.remove (nview);
         delete nview;
     }
-    KGlobal::locale()->removeCatalogue("kttsd");
+    KGlobal::locale()->removeCatalog("kttsd");
 }
 
 
@@ -72,8 +72,7 @@ KateKttsdPluginView::KateKttsdPluginView( KTextEditor::View *view, const char *n
     KXMLGUIClient( view )
 {
     view->insertChildClient( this );
-    setInstance( KGenericFactory<KateKttsdPlugin>::instance() );
-    KGlobal::locale()->insertCatalogue("kttsd");
+    setComponentData( KGenericFactory<KateKttsdPlugin>::componentData() );
     (void) new KAction( i18n("Speak Text"), "kttsd", 0, this, SLOT(slotReadOut()), actionCollection(), "tools_kttsd" );
     setXMLFile( "ktexteditor_kttsdui.rc" );
 }
@@ -91,30 +90,21 @@ void KateKttsdPluginView::slotReadOut()
         text = ei->text();
     }
 
-    DCOPClient *client = kapp->dcopClient();
     // If KTTSD not running, start it.
-    if (!client->isApplicationRegistered("kttsd"))
+    if (!QDBus::sessionBus().interface()->isServiceRegistered("org.kde.kttsd"))
     {
         QString error;
-        if (kapp->startServiceByDesktopName("kttsd", QStringList(), &error))
+        if (KToolInvocation::startServiceByDesktopName("kttsd", QStringList(), &error))
             QMessageBox::warning(0, i18n( "Starting KTTSD Failed"), error );
     }
-    QByteArray  data;
-    QByteArray  data2;
-    QCString    replyType;
-    QByteArray  replyData;
-    QDataStream arg(data, IO_WriteOnly);
-    arg << text << "";
-    if ( !client->call("kttsd", "KSpeech", "setText(QString,QString)",
-                       data, replyType, replyData, true) )
-       QMessageBox::warning( 0, i18n( "DCOP Call Failed" ),
-                                 i18n( "The DCOP call setText failed." ));
-    QDataStream arg2(data2, IO_WriteOnly);
-
-    arg2 << 0;
-    if ( !client->call("kttsd", "KSpeech", "startText(uint)",
-                       data2, replyType, replyData, true) )
-       QMessageBox::warning( 0, i18n( "DCOP Call Failed" ),
-                                i18n( "The DCOP call startText failed." ));
+	QDBusInterface kttsd( "org.kde.KSpeech", "/KSpeech", "org.kde.KSpeech" );
+	QDBusReply<bool> reply = kttsd.call("setText", text,"");
+    if ( !reply.isValid())
+       QMessageBox::warning( 0, i18n( "D-Bus Call Failed" ),
+                                 i18n( "The D-Bus call setText failed." ));
+	reply = kttsd.call("startText", 0);
+    if ( !reply.isValid())
+       QMessageBox::warning( 0, i18n( "D-Bus Call Failed" ),
+                                i18n( "The D-Bus call startText failed." ));
 }
 
