@@ -26,8 +26,9 @@
 // KDE includes.
 #include <kdebug.h>
 #include <kparts/componentfactory.h>
-#include <ktrader.h>
 #include <kstandarddirs.h>
+#include <kservicetypetrader.h>
+#include <kconfiggroup.h>
 
 // KTTS includes.
 #include "pluginconf.h"
@@ -38,9 +39,9 @@
  * Constructor.
  */
 TalkerMgr::TalkerMgr(QObject *parent, const char *name) :
-    QObject( parent, name )
+    QObject( parent )
 {
-    m_loadedPlugIns.setAutoDelete(true);
+    Q_UNUSED(name);
 }
 
 /**
@@ -48,41 +49,41 @@ TalkerMgr::TalkerMgr(QObject *parent, const char *name) :
  */
 TalkerMgr::~TalkerMgr()
 {
-    m_loadedPlugIns.clear();
+    while (!m_loadedPlugIns.isEmpty()) delete m_loadedPlugIns.takeFirst();
 }
 
 /**
  * Load all the configured synth plugins,  populating loadedPlugIns structure.
  */
-int TalkerMgr::loadPlugIns(KConfig* config)
+int TalkerMgr::loadPlugIns(KConfig* c)
 {
-    // kdDebug() << "Running: TalkerMgr::loadPlugIns()" << endl;
+    // kDebug() << "Running: TalkerMgr::loadPlugIns()";
     int good = 0;
     int bad = 0;
 
     m_talkerToPlugInCache.clear();
-    m_loadedPlugIns.clear();
+    while (!m_loadedPlugIns.isEmpty()) delete m_loadedPlugIns.takeFirst();
     m_loadedTalkerCodes.clear();
     m_loadedTalkerIds.clear();
 
-    config->setGroup("General");
-    QStringList talkerIDsList = config->readListEntry("TalkerIDs", ',');
+    KConfigGroup config(c, "General");
+    QStringList talkerIDsList = config.readEntry("TalkerIDs", QStringList());
     if (!talkerIDsList.isEmpty())
     {
         KLibFactory *factory;
         QStringList::ConstIterator itEnd(talkerIDsList.constEnd());
         for( QStringList::ConstIterator it = talkerIDsList.constBegin(); it != itEnd; ++it )
         {
-            // kdDebug() << "Loading plugInProc for Talker ID " << *it << endl;
+            // kDebug() << "Loading plugInProc for Talker ID " << *it;
 
             // Talker ID.
             QString talkerID = *it;
 
             // Set the group for the language we're loading
-            config->setGroup("Talker_" + talkerID);
+            KConfigGroup talkerConfig(c, "Talker_" + talkerID);
 
             // Get the DesktopEntryName of the plugin we will try to load.
-            QString desktopEntryName = config->readEntry("DesktopEntryName", QString::null);
+            QString desktopEntryName = talkerConfig.readEntry("DesktopEntryName", QString());
 
             // If a DesktopEntryName is not in the config file, it was configured before
             // we started using them, when we stored translated plugin names instead.
@@ -91,54 +92,54 @@ int TalkerMgr::loadPlugIns(KConfig* config)
             // and DesktopEntryName won't change.
             if (desktopEntryName.isEmpty())
             {
-                QString synthName = config->readEntry("PlugIn", QString::null);
+                QString synthName = talkerConfig.readEntry("PlugIn", QString());
                 // See if the translated name will untranslate.  If not, well, sorry.
                 desktopEntryName = TalkerCode::TalkerNameToDesktopEntryName(synthName);
                 // Record the DesktopEntryName from now on.
-                if (!desktopEntryName.isEmpty()) config->writeEntry("DesktopEntryName", desktopEntryName);
+                if (!desktopEntryName.isEmpty()) talkerConfig.writeEntry("DesktopEntryName", desktopEntryName);
             }
 
             // Get the talker code.
-            QString talkerCode = config->readEntry("TalkerCode", QString::null);
+            QString talkerCode = talkerConfig.readEntry("TalkerCode", QString());
 
             // Normalize the talker code.
             QString fullLanguageCode;
             talkerCode = TalkerCode::normalizeTalkerCode(talkerCode, fullLanguageCode);
 
             // Find the KTTSD SynthPlugin.
-            KTrader::OfferList offers = KTrader::self()->query(
+			KService::List offers = KServiceTypeTrader::self()->query(
                 "KTTSD/SynthPlugin", QString("DesktopEntryName == '%1'").arg(desktopEntryName));
 
             if(offers.count() > 1){
                 ++bad;
-                kdDebug() << "More than 1 plug in doesn't make any sense, well, let's use any" << endl;
+                kDebug() << "More than 1 plug in doesn't make any sense, well, let's use any";
             } else if(offers.count() < 1){
                 ++bad;
-                kdDebug() << "Less than 1 plug in, nothing can be done" << endl;
+                kDebug() << "Less than 1 plug in, nothing can be done";
             } else {
-                kdDebug() << "Loading " << offers[0]->library() << endl;
-                factory = KLibLoader::self()->factory(offers[0]->library().latin1());
+                kDebug() << "Loading " << offers[0]->library();
+                factory = KLibLoader::self()->factory(offers[0]->library().toLatin1());
                 if(factory){
                     PlugInProc *speech = 
-                            KParts::ComponentFactory::createInstanceFromLibrary<PlugInProc>(
-                            offers[0]->library().latin1(), this, offers[0]->library().latin1());
+                            KLibLoader::createInstance<PlugInProc>(
+                            offers[0]->library().toLatin1(), this, QStringList(offers[0]->library().toLatin1()));
                     if(!speech){
-                        kdDebug() << "Couldn't create the speech object from " << offers[0]->library() << endl;
+                        kDebug() << "Couldn't create the speech object from " << offers[0]->library();
                         ++bad;
                     } else {
                         if (speech->supportsAsync())
                         {
-                            speech->init(config, "Talker_" + talkerID);
-                            // kdDebug() << "Plug in " << desktopEntryName << " created successfully." << endl;
+                            speech->init(c, "Talker_" + talkerID);
+                            // kDebug() << "Plug in " << desktopEntryName << " created successfully.";
                             m_loadedPlugIns.append(speech);
                         } else {
                             // Synchronous plugins are run in a separate thread.
                             // Init will start the thread and it will immediately go to sleep.
                             QString threadedPlugInName = QString::fromLatin1("threaded") + desktopEntryName;
                             ThreadedPlugIn* speechThread = new ThreadedPlugIn(speech,
-                                    this, threadedPlugInName.latin1());
-                            speechThread->init(config, "Talker_" + talkerCode);
-                            // kdDebug() << "Threaded Plug in " << desktopEntryName << " for language " <<  (*it).right((*it).length()-5) << " created succesfully." << endl;
+                                    this, threadedPlugInName.toLatin1());
+                            speechThread->init(c, "Talker_" + talkerCode);
+                            // kDebug() << "Threaded Plug in " << desktopEntryName << " for language " <<  (*it).right((*it).length()-5) << " created successfully.";
                             m_loadedPlugIns.append(speechThread);
                         }
                         ++good;
@@ -146,7 +147,7 @@ int TalkerMgr::loadPlugIns(KConfig* config)
                         m_loadedTalkerIds.append(talkerID);
                     }
                 } else {
-                    kdDebug() << "Couldn't create the factory object from " << offers[0]->library() << endl;
+                    kDebug() << "Couldn't create the factory object from " << offers[0]->library();
                     ++bad;
                 }
             }
@@ -188,7 +189,7 @@ QStringList TalkerMgr::getTalkers()
 /**
  * Returns a list of all the loaded plugins.
  */
-QPtrList<PlugInProc> TalkerMgr::getLoadedPlugIns()
+PlugInList TalkerMgr::getLoadedPlugIns()
 {
     return m_loadedPlugIns;
 }
@@ -203,7 +204,7 @@ QPtrList<PlugInProc> TalkerMgr::getLoadedPlugIns()
  */
 int TalkerMgr::talkerToPluginIndex(const QString& talker) const
 {
-    // kdDebug() << "TalkerMgr::talkerToPluginIndex: matching talker " << talker << " to closest matching plugin." << endl;
+    // kDebug() << "TalkerMgr::talkerToPluginIndex: matching talker " << talker << " to closest matching plugin.";
     // If we have a cached match, return that.
     if (m_talkerToPlugInCache.contains(talker))
         return m_talkerToPlugInCache[talker];
@@ -231,7 +232,7 @@ int TalkerMgr::talkerToPluginIndex(const QString& talker) const
 PlugInProc* TalkerMgr::talkerToPlugin(const QString& talker) const
 {
     int talkerNdx = talkerToPluginIndex(talker);
-    return const_cast< QPtrList<PlugInProc>* >(&m_loadedPlugIns)->at(talkerNdx);
+    return const_cast< PlugInList* >(&m_loadedPlugIns)->at(talkerNdx);
 }
 
 /**
@@ -290,7 +291,7 @@ QString TalkerMgr::userDefaultTalker() const
  */
 bool TalkerMgr::supportsMarkup(const QString& talker, const uint /*markupType*/) const
 {
-    kdDebug() << "TalkerMgr::supportsMarkup: Testing talker " << talker << endl;
+    kDebug() << "TalkerMgr::supportsMarkup: Testing talker " << talker;
     QString matchingTalker = talker;
     if (matchingTalker.isEmpty()) matchingTalker = userDefaultTalker();
     PlugInProc* plugin = talkerToPlugin(matchingTalker);
@@ -306,9 +307,10 @@ bool TalkerMgr::autoconfigureTalker(const QString& langCode, KConfig* config)
     QString languageCode = langCode;
 
     // Get last TalkerID from config.
-    QStringList talkerIDsList = config->readListEntry("TalkerIDs", ',');
+    KConfigGroup generalConfig(config, "General");
+    QStringList talkerIDsList = generalConfig.readEntry("TalkerIDs", QStringList());
     int lastTalkerID = 0;
-    for (uint talkerIdNdx = 0; talkerIdNdx < talkerIDsList.count(); ++talkerIdNdx)
+    for (int talkerIdNdx = 0; talkerIdNdx < talkerIDsList.count(); ++talkerIdNdx)
     {
         int id = talkerIDsList[talkerIdNdx].toInt();
         if (id > lastTalkerID) lastTalkerID = id;
@@ -318,10 +320,10 @@ bool TalkerMgr::autoconfigureTalker(const QString& langCode, KConfig* config)
     QString talkerID = QString::number(lastTalkerID + 1);
 
     // Query for all the KTTSD SynthPlugins.
-    KTrader::OfferList offers = KTrader::self()->query("KTTSD/SynthPlugin");
+    KService::List offers = KServiceTypeTrader::self()->query("KTTSD/SynthPlugin");
 
     // Iterate thru the possible plug ins.
-    for(unsigned int i=0; i < offers.count() ; ++i)
+    for(int i=0; i < offers.count() ; ++i)
     {
         // See if this plugin supports the desired language.
         QStringList languageCodes = offers[i]->property("X-KDE-Languages").toStringList();
@@ -330,14 +332,14 @@ bool TalkerMgr::autoconfigureTalker(const QString& langCode, KConfig* config)
             QString desktopEntryName = offers[i]->desktopEntryName();
 
             // Load the plugin.
-            KLibFactory *factory = KLibLoader::self()->factory(offers[0]->library().latin1());
+            KLibFactory *factory = KLibLoader::self()->factory(offers[0]->library().toLatin1());
             if (factory)
             {
                 // If the factory is created successfully, instantiate the PlugInConf class for the
                 // specific plug in to get the plug in configuration object.
                 PlugInConf* loadedTalkerPlugIn =
-                    KParts::ComponentFactory::createInstanceFromLibrary<PlugInConf>(
-                        offers[0]->library().latin1(), NULL, offers[0]->library().latin1());
+                    KLibLoader::createInstance<PlugInConf>(
+                        offers[0]->library().toLatin1(), NULL, QStringList(offers[0]->library().toLatin1()));
                 if (loadedTalkerPlugIn)
                 {
                     // Give plugin the language code and permit plugin to autoconfigure itself.
@@ -353,19 +355,17 @@ bool TalkerMgr::autoconfigureTalker(const QString& langCode, KConfig* config)
                         config->deleteGroup(QString("Talker_")+talkerID);
 
                         // Let plugin save its configuration.
-                        config->setGroup(QString("Talker_")+talkerID);
                         loadedTalkerPlugIn->save(config, QString("Talker_"+talkerID));
 
                         // Record configuration data.
-                        config->setGroup(QString("Talker_")+talkerID);
-                        config->writeEntry("DesktopEntryName", desktopEntryName);
+                        KConfigGroup talkerConfig(config, QString("Talker_")+talkerID);
+                        talkerConfig.writeEntry("DesktopEntryName", desktopEntryName);
                         talkerCode = TalkerCode::normalizeTalkerCode(talkerCode, languageCode);
-                        config->writeEntry("TalkerCode", talkerCode);
+                        talkerConfig.writeEntry("TalkerCode", talkerCode);
 
                         // Add TalkerID to configured list.
                         talkerIDsList.append(talkerID);
-                        config->setGroup("General");
-                        config->writeEntry("TalkerIDs", talkerIDsList.join(","));
+                        generalConfig.writeEntry("TalkerIDs", talkerIDsList.join(","));
                         config->sync();
 
                         // TODO: Now that we have modified the config, need a way to inform
