@@ -16,8 +16,8 @@
  ***************************************************************************/
 
 // Qt includes. 
-#include <qstring.h>
-#include <qtextcodec.h>
+
+#include <QtCore/QTextCodec>
 
 // KDE includes.
 #include <kdebug.h>
@@ -31,22 +31,23 @@
 /**
 * Constructor
 */
-PlugInProc::PlugInProc( QObject *parent, const char *name) : QObject(parent, name){
-    // kdDebug() << "PlugInProc::PlugInProc: Running" << endl;
+PlugInProc::PlugInProc( QObject *parent, const char *name) : QObject(parent){
+    setObjectName(name);
+    // kDebug() << "PlugInProc::PlugInProc: Running";
 }
 
 /**
 * Destructor
 */
 PlugInProc::~PlugInProc(){
-    // kdDebug() << "PlugInProc::~PlugInProc: Running" << endl;
+    // kDebug() << "PlugInProc::~PlugInProc: Running";
 }
 
 /**
 * Initializate the speech plugin.
 */
 bool PlugInProc::init(KConfig* /*config*/, const QString& /*configGroup*/){
-    // kdDebug() << "PlugInProc::init: Running" << endl;
+    // kDebug() << "PlugInProc::init: Running";
     return false;
 }
 
@@ -57,7 +58,7 @@ bool PlugInProc::init(KConfig* /*config*/, const QString& /*configGroup*/){
 * If the plugin supports asynchronous operation, it should return immediately.
 */
 void PlugInProc::sayText(const QString& /*text*/){
-    // kdDebug() << "PlugInProc::sayText: Running" << endl;
+    // kDebug() << "PlugInProc::sayText: Running";
 }
 
 /**
@@ -79,7 +80,7 @@ void PlugInProc::synthText(const QString& /*text*/, const QString& /*suggestedFi
 *
 * The plugin must not re-use the filename.
 */
-QString PlugInProc::getFilename() { return QString::null; }
+QString PlugInProc::getFilename() { return QString(); }
 
 /**
 * Stop current operation (saying or synthesizing text).
@@ -87,7 +88,7 @@ QString PlugInProc::getFilename() { return QString::null; }
 * The plugin should return to the psIdle state.
 */
 void PlugInProc::stopText(){
-    // kdDebug() << "PlugInProc::stopText: Running" << endl;
+    // kDebug() << "PlugInProc::stopText: Running";
 }
 
 /**
@@ -160,11 +161,11 @@ QString PlugInProc::getSsmlXsltFilename()
     else if (codecName == "Unicode")
         codec = QTextCodec::codecForName("utf16");
     else
-        codec = QTextCodec::codecForName(codecName.latin1());
+        codec = QTextCodec::codecForName(codecName.toLatin1());
     if (!codec)
     {
-        kdDebug() << "PluginProc::codecNameToCodec: Invalid codec name " << codecName << endl;
-        kdDebug() << "PluginProc::codecNameToCodec: Defaulting to ISO 8859-1" << endl;
+        kDebug() << "PluginProc::codecNameToCodec: Invalid codec name " << codecName;
+        kDebug() << "PluginProc::codecNameToCodec: Defaulting to ISO 8859-1";
         codec = QTextCodec::codecForName("ISO8859-1");
     }
     return codec;
@@ -179,16 +180,17 @@ QString PlugInProc::getSsmlXsltFilename()
 */
 /*static*/ QStringList PlugInProc::buildCodecList()
 {
-    // kdDebug() << "PlugInConf::buildCodecList: Running" << endl;
+    // kDebug() << "PlugInConf::buildCodecList: Running";
     QStringList codecList;
     QString local = i18n("Local")+" (";
     local += QTextCodec::codecForLocale()->name();
-    local += ")";
+    local += ')';
     codecList.append(local);
     codecList.append(i18n("Latin1"));
     codecList.append(i18n("Unicode"));
-    for (int i = 0; (QTextCodec::codecForIndex(i)); ++i )
-        codecList.append(QTextCodec::codecForIndex(i)->name());
+    QList<QByteArray> availableCodecs = QTextCodec::availableCodecs();
+    for (int i = 0; i < availableCodecs.size(); ++i )
+        codecList.append(availableCodecs.at(i));
     return codecList;
 }
 
@@ -243,13 +245,13 @@ QString PlugInProc::getSsmlXsltFilename()
             codec = QTextCodec::codecForName("utf16");
             break;
         default:
-            codec = QTextCodec::codecForName(codecList[codecNum].latin1());
+            codec = QTextCodec::codecForName(codecList[codecNum].toLatin1());
             break;
     }
     if (!codec)
     {
-        kdDebug() << "PlugInProc::codecIndexToCodec: Invalid codec index " << codecNum << endl;
-        kdDebug() << "PlugInProc::codecIndexToCodec: Defaulting to ISO 8859-1" << endl;
+        kDebug() << "PlugInProc::codecIndexToCodec: Invalid codec index " << codecNum;
+        kDebug() << "PlugInProc::codecIndexToCodec: Defaulting to ISO 8859-1";
         codec = QTextCodec::codecForName("ISO8859-1");
     }
     return codec;
@@ -279,12 +281,12 @@ QString PlugInProc::getSsmlXsltFilename()
             codecName = "Unicode";
             break;
         default:
-            if ((uint)codecNum < codecList.count())
+            if (codecNum < codecList.count())
                 codecName = codecList[codecNum];
             else
             {
-                kdDebug() << "PlugInProc::codecIndexToCodec: Invalid codec index " << codecNum << endl;
-                kdDebug() << "PlugInProc::codecIndexToCodec: Defaulting to ISO 8859-1" << endl;
+                kDebug() << "PlugInProc::codecIndexToCodec: Invalid codec index " << codecNum;
+                kDebug() << "PlugInProc::codecIndexToCodec: Defaulting to ISO 8859-1";
                 codecName = "ISO8859-1";
             }
     }
