@@ -25,28 +25,27 @@
 #define _EPOSCONF_H_
 
 // Qt includes.
-#include <qstring.h>
+
 
 // KDE includes.
 #include <kconfig.h>
 #include <kdebug.h>
-#include <kprogress.h>
 
 // KTTS includes.
 #include <pluginconf.h>
 
 // Epos plugin includes.
-#include "eposconfwidget.h"
+#include "ui_eposconfwidget.h"
 
 class EposProc;
 class KProgressDialog;
 
-class EposConf : public PlugInConf {
+class EposConf : public PlugInConf, public Ui::EposConfWidget {
     Q_OBJECT 
 
     public:
         /** Constructor */
-        EposConf( QWidget* parent = 0, const char* name = 0, const QStringList &args = QStringList());
+        explicit EposConf( QWidget* parent = 0, const QStringList &args = QStringList());
 
         /** Destructor */
         ~EposConf();
@@ -78,7 +77,7 @@ class EposConf : public PlugInConf {
         * This function informs the plugin of the desired language to be spoken
         * by the plugin.  The plugin should attempt to adapt itself to the
         * specified language code, choosing sensible defaults if necessary.
-        * If the passed-in code is QString::null, no specific language has
+        * If the passed-in code is QString(), no specific language has
         * been chosen.
         * @param lang        The desired language code or Null if none.
         *
@@ -96,16 +95,16 @@ class EposConf : public PlugInConf {
         * Return fully-specified talker code for the configured plugin.  This code
         * uniquely identifies the configured instance of the plugin and distinquishes
         * one instance from another.  If the plugin has not been fully configured,
-        * i.e., cannot yet synthesize, return QString::null.
+        * i.e., cannot yet synthesize, return QString().
         * @return            Fully-specified talker code.
         */
         QString getTalkerCode();
 
     private slots:
         void configChanged(){
-            kdDebug() << "EposConf::configChanged: Running" << endl;
+            kDebug() << "EposConf::configChanged: Running";
             emit changed(true);
-        };
+        }
         void slotEposTest_clicked();
         void slotSynthFinished();
         void slotSynthStopped();
@@ -126,10 +125,7 @@ class EposConf : public PlugInConf {
         // Language code.
         QString m_languageCode;
 
-        // Configuration widget.
-        EposConfWidget* m_widget;
-
-        // Epos synthesizer.
+       // Epos synthesizer.
         EposProc* m_eposProc;
         // Synthesized wave file name.
         QString m_waveFile;
