@@ -26,13 +26,13 @@
 #define _EPOSPROC_H_
 
 // Qt includes.
-#include <qstringlist.h>
-#include <qmutex.h>
+#include <QtCore/QMutex>
+#include <QtCore/QByteArray>
 
 // KTTS includes.
 #include <pluginproc.h>
 
-class KProcess;
+class K3Process;
 class QTextCodec;
 
 class EposProc : public PlugInProc{
@@ -42,7 +42,7 @@ class EposProc : public PlugInProc{
         /**
          * Constructor
          */
-        EposProc( QObject* parent = 0, const char* name = 0, const QStringList &args = QStringList());
+        explicit EposProc( QObject* parent = 0, const QStringList &args = QStringList());
 
         /**
          * Destructor
@@ -55,7 +55,7 @@ class EposProc : public PlugInProc{
          * @param configGroup     Settings group.
          */
         virtual bool init(KConfig *config, const QString &configGroup);
-
+        
         /**
          * Say a text string.
          * @param text            The text to speak.
@@ -73,7 +73,7 @@ class EposProc : public PlugInProc{
         * If the plugin supports asynchronous operation, it should return immediately.
         */
         virtual void synthText(const QString& text, const QString& suggestedFilename);
-
+        
         /**
         * Get the generated audio filename from synthText.
         * @return                        Name of the audio file the plugin generated.
@@ -82,7 +82,7 @@ class EposProc : public PlugInProc{
         * The plugin must not re-use the filename.
         */
         virtual QString getFilename();
-
+        
         /**
         * Stop current operation (saying or synthesizing text).
         * Important: This function may be called from a thread different from the
@@ -99,7 +99,7 @@ class EposProc : public PlugInProc{
         * operation.
         */
         virtual void stopText();
-
+        
         /**
         * Return the current state of the plugin.
         * This function only makes sense in asynchronous mode.
@@ -108,7 +108,7 @@ class EposProc : public PlugInProc{
         * @see pluginState
         */
         virtual pluginState getState();
-
+        
         /**
         * Acknowledges a finished state and resets the plugin state to psIdle.
         *
@@ -118,7 +118,7 @@ class EposProc : public PlugInProc{
         * Calling program should call getFilename prior to ackFinished.
         */
         virtual void ackFinished();
-
+        
         /**
         * Returns True if the plugin supports asynchronous processing,
         * i.e., returns immediately from sayText or synthText.
@@ -129,7 +129,7 @@ class EposProc : public PlugInProc{
         * saying or synthesis is completed.
         */
         virtual bool supportsAsync();
-
+        
         /**
         * Returns True if the plugin supports synthText method,
         * i.e., is able to synthesize text to a sound file without
@@ -137,7 +137,7 @@ class EposProc : public PlugInProc{
         * @return                        True if this plugin supports synthText method.
         */
         virtual bool supportsSynth();
-
+    
         /**
         * Say or Synthesize text.
         * @param text                    The text to be synthesized.
@@ -164,78 +164,78 @@ class EposProc : public PlugInProc{
             const QString& eposLanguage,
             int time,
             int pitch);
-
+    
     private slots:
-        void slotProcessExited(KProcess* proc);
-        void slotReceivedStdout(KProcess* proc, char* buffer, int buflen);
-        void slotReceivedStderr(KProcess* proc, char* buffer, int buflen);
-        void slotWroteStdin(KProcess* proc);
+        void slotProcessExited(K3Process* proc);
+        void slotReceivedStdout(K3Process* proc, char* buffer, int buflen);
+        void slotReceivedStderr(K3Process* proc, char* buffer, int buflen);
+        void slotWroteStdin(K3Process* proc);
 
     private:
-
+        
         /**
         * Path to epos executables (from config).
         */
         QString m_eposServerExePath;
         QString m_eposClientExePath;
-
+        
         /**
         * User options passed to executables (from config).
         */
         QString m_eposServerOptions;
         QString m_eposClientOptions;
-
+        
         /**
         * Epos Server process.
         */
-        KProcess* m_eposServerProc;
-
+        K3Process* m_eposServerProc;
+                
         /**
          * Epos Client process
          */
-        KProcess* m_eposProc;
-
+        K3Process* m_eposProc;
+        
         /**
         * Epos language setting.  "czech", "slovak", or Null (use default language).
         */
         QString m_eposLanguage;
-
+        
         /**
         * Rate (speed) from config file.
         */
         int m_time;
-
+        
         /**
         * Pitch from the config file.
         */
         int m_pitch;
-
+        
         /**
         * Codec.
         */
         QTextCodec* m_codec;
-
+        
         /**
         * Encoded buffer to be sent to Epos client.
          */
-        QCString m_encText;
-
+        QByteArray m_encText;
+        
         /**
         * Synthesis filename.
         */
         QString m_synthFilename;
-
+        
         /**
         * Plugin state.
         */
         pluginState m_state;
-
+        
         /**
         * True when stopText has been called.  Used to force transition to psIdle when
         * Epos exits.
         */
         bool m_waitingStop;
-
+        
 };
 
 #endif // _EPOSPROC_H_
