@@ -1,32 +1,38 @@
 /***************************************************** vim:set ts=4 sw=4 sts=4:
   Main speaking functions for the Festival (Interactive) Plug in
   -------------------
-  Copyright : (C) 2004 Gary Cramblitt
+  Copyright:
+  (C) 2004 by Gary Cramblitt <garycramblitt@comcast.net>
   -------------------
   Original author: Gary Cramblitt <garycramblitt@comcast.net>
-  Current Maintainer: Gary Cramblitt <garycramblitt@comcast.net>
- ******************************************************************************/
 
-/***************************************************************************
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; version 2 of the License.               *
- *                                                                         *
- ***************************************************************************/
+  This program is free software; you can redistribute it and/or modify
+  it under the terms of the GNU General Public License as published by
+  the Free Software Foundation; either version 2 of the License, or
+  (at your option) any later version.
+
+  This program is distributed in the hope that it will be useful,
+  but WITHOUT ANY WARRANTY; without even the implied warranty of
+  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+  GNU General Public License for more details.
+
+  You should have received a copy of the GNU General Public License
+  along with this program; if not, write to the Free Software
+  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
+ ******************************************************************************/
 
 // C++ includes.
 #include <math.h>
 
 // Qt includes.
-#include <qstring.h>
-#include <qstringlist.h>
-#include <qthread.h>
-#include <qtextcodec.h>
+#include <QtCore/QThread>
+#include <QtCore/QTextCodec>
+#include <QtCore/QByteArray>
 
 // KDE includes.
 #include <kdebug.h>
 #include <kconfig.h>
+#include <kconfiggroup.h>
 #include <kstandarddirs.h>
 
 // KTTS includes.
@@ -37,22 +43,23 @@
 #include "festivalintproc.moc"
 
 /** Constructor */
-FestivalIntProc::FestivalIntProc( QObject* parent, const char* name, const QStringList& ) : 
-    PlugInProc( parent, name ){
-    // kdDebug() << "FestivalIntProc::FestivalIntProc: Running" << endl;
+FestivalIntProc::FestivalIntProc( QObject* parent, const QStringList& ) : 
+    PlugInProc( parent, "festivalintproc" ){
+    // kDebug() << "FestivalIntProc::FestivalIntProc: Running";
     m_ready = true;
     m_writingStdin = false;
     m_waitingQueryVoices = false;
     m_waitingStop = false;
     m_festProc = 0;
     m_state = psIdle;
+    m_supportsSSML = ssUnknown;
     m_languageCode = "en";
     m_codec = QTextCodec::codecForName("ISO8859-1");
 }
 
 /** Destructor */
 FestivalIntProc::~FestivalIntProc(){
-    // kdDebug() << "FestivalIntProc::~FestivalIntProc: Running" << endl;
+    // kDebug() << "FestivalIntProc::~FestivalIntProc: Running";
     if (m_festProc)
     {
         if (m_festProc->isRunning())
@@ -60,14 +67,14 @@ FestivalIntProc::~FestivalIntProc(){
             if (m_ready)
             {
                 m_state = psIdle;
-                // kdDebug() << "FestivalIntProc::~FestivalIntProc: telling Festival to quit." << endl;
+                // kDebug() << "FestivalIntProc::~FestivalIntProc: telling Festival to quit.";
                 m_ready = false;
                 m_waitingStop = true;
                 m_festProc->writeStdin("(quit)", true);
             }
             else
             {
-                // kdDebug() << "FestivalIntProc::~FestivalIntProc: killing Festival." << endl;
+                // kDebug() << "FestivalIntProc::~FestivalIntProc: killing Festival.";
                 m_waitingStop = true;
                 m_festProc->kill();
             }
@@ -77,21 +84,22 @@ FestivalIntProc::~FestivalIntProc(){
 }
 
 /** Initialize the speech */
-bool FestivalIntProc::init(KConfig *config, const QString &configGroup)
+bool FestivalIntProc::init(KConfig *c, const QString &configGroup)
 {
-    // kdDebug() << "FestivalIntProc::init: Initializing plug in: Festival" << endl;
+    // kDebug() << "FestivalIntProc::init: Initializing plug in: Festival";
 
-    config->setGroup(configGroup);
-    m_voiceCode = config->readEntry("Voice");
-    m_festivalExePath = config->readEntry("FestivalExecutablePath", "festival");
-    // kdDebug() << "---- The code for the selected voice " << config->readEntry("Voice") << " is " << voiceCode << endl;
-    m_time = config->readNumEntry("time", 100);
-    m_pitch = config->readNumEntry("pitch", 100);
-    m_volume = config->readNumEntry("volume", 100);
+    KConfigGroup config(c, configGroup);
+    m_voiceCode = config.readEntry("Voice");
+    m_festivalExePath = config.readEntry("FestivalExecutablePath", "festival");
+    // kDebug() << "---- The code for the selected voice " << config.readEntry("Voice") << " is " << voiceCode;
+    m_time = config.readEntry("time", 100);
+    m_pitch = config.readEntry("pitch", 100);
+    m_volume = config.readEntry("volume", 100);
     // If voice should be pre-loaded, start Festival and load the voice.
-    m_preload = config->readBoolEntry("Preload", false);
-    m_languageCode = config->readEntry("LanguageCode", "en");
-    QString codecName = config->readEntry("Codec", "Latin1");
+    m_preload = config.readEntry("Preload", false);
+    m_languageCode = config.readEntry("LanguageCode", "en");
+    m_supportsSSML = static_cast<SupportsSSML>(config.readEntry("SupportsSSML", int(ssUnknown)));
+    QString codecName = config.readEntry("Codec", "Latin1");
     m_codec = codecNameToCodec(codecName);
     if (m_preload) startEngine(m_festivalExePath, m_voiceCode, m_languageCode, m_codec);
     return true;
@@ -105,7 +113,7 @@ bool FestivalIntProc::init(KConfig *config, const QString &configGroup)
 */
 void FestivalIntProc::sayText(const QString &text)
 {
-    synth(m_festivalExePath, text, QString::null, m_voiceCode, m_time, m_pitch, m_volume,
+    synth(m_festivalExePath, text, QString(), m_voiceCode, m_time, m_pitch, m_volume,
         m_languageCode, m_codec);
 }
 
@@ -123,7 +131,7 @@ void FestivalIntProc::synthText(const QString& text, const QString& suggestedFil
 {
     synth(m_festivalExePath, text, suggestedFilename, m_voiceCode, m_time, m_pitch, m_volume,
         m_languageCode, m_codec);
-};
+}
 
 /**
 * Sends command to Festival to query for a list of supported voice codes.
@@ -133,12 +141,14 @@ void FestivalIntProc::synthText(const QString& text, const QString& suggestedFil
 */
 bool FestivalIntProc::queryVoices(const QString &festivalExePath)
 {
-    // kdDebug() << "FestivalIntProc::queryVoices: Running" << endl;
+    // kDebug() << "FestivalIntProc::queryVoices: Running";
     if (m_state != psIdle && m_waitingQueryVoices && m_waitingStop) return false;
     // Start Festival if not already running.
-    startEngine(festivalExePath, QString::null, m_languageCode, m_codec);
+    startEngine(festivalExePath, QString(), m_languageCode, m_codec);
     // Set state, waiting for voice codes list from Festival.
     m_waitingQueryVoices = true;
+    // Voice rab_diphone is needed in order to support SSML.
+    m_supportsSSML = ssUnknown;
     // Send command to query the voice codes.
     sendToFestival("(print (mapcar (lambda (pair) (car pair)) voice-locations))");
     return true;
@@ -167,33 +177,33 @@ void FestivalIntProc::startEngine(const QString &festivalExePath, const QString
     }
     if(!m_festProc)
     {
-        // kdDebug()<< "FestivalIntProc::startEngine: Creating Festival object" << endl;
-        m_festProc = new KProcess;
+        // kDebug()<< "FestivalIntProc::startEngine: Creating Festival object";
+        m_festProc = new K3Process;
         *m_festProc << festivalExePath;
         *m_festProc << "--interactive";
-        m_festProc->setEnvironment("LANG", languageCode + "." + codec->mimeName());
-        m_festProc->setEnvironment("LC_CTYPE", languageCode + "." + codec->mimeName());
-        kdDebug() << "FestivalIntProc::startEngine: setting LANG = LC_CTYPE = " << languageCode << "." << codec->mimeName() << endl;
-        connect(m_festProc, SIGNAL(processExited(KProcess*)),
-                this, SLOT(slotProcessExited(KProcess*)));
-        connect(m_festProc, SIGNAL(receivedStdout(KProcess*, char*, int)),
-                this, SLOT(slotReceivedStdout(KProcess*, char*, int)));
-        connect(m_festProc, SIGNAL(receivedStderr(KProcess*, char*, int)),
-                this, SLOT(slotReceivedStderr(KProcess*, char*, int)));
-        connect(m_festProc, SIGNAL(wroteStdin(KProcess*)),
-                this, SLOT(slotWroteStdin(KProcess*)));
+        m_festProc->setEnvironment("LANG", languageCode + '.' + codec->name());
+        m_festProc->setEnvironment("LC_CTYPE", languageCode + '.' + codec->name());
+        // kDebug() << "FestivalIntProc::startEngine: setting LANG = LC_CTYPE = " << languageCode << "." << codec->mimeName();
+        connect(m_festProc, SIGNAL(processExited(K3Process*)),
+                this, SLOT(slotProcessExited(K3Process*)));
+        connect(m_festProc, SIGNAL(receivedStdout(K3Process*, char*, int)),
+                this, SLOT(slotReceivedStdout(K3Process*, char*, int)));
+        connect(m_festProc, SIGNAL(receivedStderr(K3Process*, char*, int)),
+                this, SLOT(slotReceivedStderr(K3Process*, char*, int)));
+        connect(m_festProc, SIGNAL(wroteStdin(K3Process*)),
+                this, SLOT(slotWroteStdin(K3Process*)));
     }
     if (!m_festProc->isRunning())
     {
-        // kdDebug() << "FestivalIntProc::startEngine: Starting Festival process" << endl;
-        m_runningVoiceCode = QString::null;
+        // kDebug() << "FestivalIntProc::startEngine: Starting Festival process";
+        m_runningVoiceCode.clear();
         m_runningTime = 100;
         m_runningPitch = 100;
         m_ready = false;
         m_outputQueue.clear();
-        if (m_festProc->start(KProcess::NotifyOnExit, KProcess::All))
+        if (m_festProc->start(K3Process::NotifyOnExit, K3Process::All))
         {
-            // kdDebug()<< "FestivalIntProc:startEngine: Festival initialized" << endl;
+            // kDebug()<< "FestivalIntProc:startEngine: Festival initialized";
             m_festivalExePath = festivalExePath;
             m_languageCode = languageCode;
             m_codec = codec;
@@ -203,7 +213,7 @@ void FestivalIntProc::startEngine(const QString &festivalExePath, const QString
         }
         else
         {
-            kdDebug() << "FestivalIntProc::startEngine: Error starting Festival process.  Is festival in the PATH?" << endl;
+            kDebug() << "FestivalIntProc::startEngine: Error starting Festival process.  Is festival in the PATH?";
             m_ready = true;
             m_state = psIdle;
             return;
@@ -211,7 +221,7 @@ void FestivalIntProc::startEngine(const QString &festivalExePath, const QString
     }
     // If we just started Festival, or voiceCode has changed, send code to Festival.
     if (m_runningVoiceCode != voiceCode && !voiceCode.isEmpty()) {
-        sendToFestival("(voice_" + voiceCode + ")");
+        sendToFestival("(voice_" + voiceCode + ')');
         m_runningVoiceCode = voiceCode;
     }
 }
@@ -239,7 +249,7 @@ void FestivalIntProc::synth(
     const QString &languageCode,
     QTextCodec* codec)
 {
-    // kdDebug() << "FestivalIntProc::synth: festivalExePath = " << festivalExePath
+    // kDebug() << "FestivalIntProc::synth: festivalExePath = " << festivalExePath
     //         << " voiceCode = " << voiceCode << endl;
 
     // Initialize Festival only if it's not initialized
@@ -287,8 +297,28 @@ void FestivalIntProc::synth(
         m_runningPitch = pitch;
     }
 
-    // Encode quotation characters.
     QString saidText = text;
+
+    // Split really long sentences into shorter sentences, by looking for commas and converting
+    // to periods.
+    int len = saidText.length();
+    while (len > c_tooLong)
+    {
+        len = saidText.lastIndexOf( ", ", len - (c_tooLong * 2 / 3), Qt::CaseSensitive );
+        if (len != -1)
+        {
+            QString c = saidText.mid(len+2, 1);
+            if (c != c.toUpper())
+            {
+                saidText.replace(len, 2, ". ");
+                saidText.replace(len+2, 1, c.toUpper());
+                kDebug() << "FestivalIntProc::synth: Splitting long sentence at " << len;
+                // kDebug() << saidText;
+            }
+        }
+    }
+
+    // Encode quotation characters.
     saidText.replace("\\\"", "#!#!");
     saidText.replace("\"", "\\\"");
     saidText.replace("#!#!", "\\\"");
@@ -299,8 +329,8 @@ void FestivalIntProc::synth(
     if (synthFilename.isNull())
     {
         m_state = psSaying;
-        m_synthFilename = QString::null;
-        // kdDebug() << "FestivalIntProc::synth: Saying text: '" << saidText << "' using Festival plug in with voice "
+        m_synthFilename.clear();
+        // kDebug() << "FestivalIntProc::synth: Saying text: '" << saidText << "' using Festival plug in with voice "
         //    << voiceCode << endl;
         saidText = "(SayText \"" + saidText + "\")";
         sendToFestival(saidText);
@@ -313,7 +343,7 @@ void FestivalIntProc::synth(
         float volumeValue = float(volume) / 100;
         // Expand to range .25 to 4.
         // float volumeValue = exp(log(volumeValue) * 2);
-        // kdDebug() << "FestivalIntProc::synth: Synthing text: '" << saidText << "' using Festival plug in with voice "
+        // kDebug() << "FestivalIntProc::synth: Synthing text: '" << saidText << "' using Festival plug in with voice "
         //    << voiceCode << endl;
         if (isSable(saidText))
         {
@@ -321,7 +351,7 @@ void FestivalIntProc::synth(
             saidText =
                 "(ktts_sabletowave \"" + saidText + "\" \"" +
                 synthFilename + "\" " +
-                QString::number(volumeValue) + ")";
+                QString::number(volumeValue) + ')';
         }
         else
         {
@@ -366,15 +396,15 @@ bool FestivalIntProc::sendIfReady()
     if (m_outputQueue.isEmpty()) return false;
     if (!m_festProc->isRunning()) return false;
     QString text = m_outputQueue[0];
-    text += "\n";
-    QCString encodedText;
+    text += '\n';
+    QByteArray encodedText;
     if (m_codec)
         encodedText = m_codec->fromUnicode(text);
     else
-        encodedText = text.latin1();  // Should not happen, but just in case.
+        encodedText = text.toLatin1();  // Should not happen, but just in case.
     m_outputQueue.pop_front();
     m_ready = false;
-    // kdDebug() << "FestivalIntProc::sendIfReady: sending to Festival: " << text << endl;
+    // kDebug() << "FestivalIntProc::sendIfReady: sending to Festival: " << text;
     m_writingStdin = true;
     m_festProc->writeStdin(encodedText, encodedText.length());
     return true;
@@ -402,7 +432,7 @@ QString FestivalIntProc::getFilename() { return m_synthFilename; }
  * Stop text
  */
 void FestivalIntProc::stopText(){
-    // kdDebug() << "FestivalIntProc::stopText: Running" << endl;
+    // kDebug() << "FestivalIntProc::stopText: Running";
     if (m_festProc)
     {
         if (m_festProc->isRunning())
@@ -417,11 +447,11 @@ void FestivalIntProc::stopText(){
                 if (m_preload && (m_state == psSynthing))
                 {
                     m_waitingStop = true;
-                    // kdDebug() << "FestivalIntProc::stopText: Optimizing stopText() for preloaded voice." << endl;
+                    // kDebug() << "FestivalIntProc::stopText: Optimizing stopText() for preloaded voice.";
                 }
                 else
                 {
-                    // kdDebug() << "FestivalIntProc::stopText: killing Festival." << endl;
+                    // kDebug() << "FestivalIntProc::stopText: killing Festival.";
                     m_waitingStop = true;
                     m_festProc->kill();
                 }
@@ -430,9 +460,9 @@ void FestivalIntProc::stopText(){
     } else m_state = psIdle;
 }
 
-void FestivalIntProc::slotProcessExited(KProcess*)
+void FestivalIntProc::slotProcessExited(K3Process*)
 {
-    // kdDebug() << "FestivalIntProc:slotProcessExited: Festival process has exited." << endl;
+    // kDebug() << "FestivalIntProc:slotProcessExited: Festival process has exited.";
     m_ready = true;
     pluginState prevState = m_state;
     if (m_waitingStop || m_waitingQueryVoices)
@@ -441,12 +471,12 @@ void FestivalIntProc::slotProcessExited(KProcess*)
         {
             m_waitingStop = false;
             m_state = psIdle;
-            // kdDebug() << "FestivalIntProc::slotProcessExited: emitting stopped signal" << endl;
+            // kDebug() << "FestivalIntProc::slotProcessExited: emitting stopped signal";
             emit stopped();
         }
         if (m_waitingQueryVoices)
         {
-            // kdDebug() << "FestivalIntProc::slotProcessExited: canceling queryVoices operation" << endl;
+            // kDebug() << "FestivalIntProc::slotProcessExited: canceling queryVoices operation";
             m_waitingQueryVoices = false;
             m_state = psIdle;
         }
@@ -454,12 +484,12 @@ void FestivalIntProc::slotProcessExited(KProcess*)
         if (m_state != psIdle) m_state = psFinished;
         if (prevState == psSaying)
         {
-            // kdDebug() << "FestivalIntProc::slotProcessExited: emitting sayFinished signal" << endl;
+            // kDebug() << "FestivalIntProc::slotProcessExited: emitting sayFinished signal";
             emit sayFinished();
         } else
             if (prevState == psSynthing)
             {
-                // kdDebug() << "FestivalIntProc::slotProcessExited: emitting synthFinished signal" << endl;
+                // kDebug() << "FestivalIntProc::slotProcessExited: emitting synthFinished signal";
                 emit synthFinished();
             }
     }
@@ -468,43 +498,48 @@ void FestivalIntProc::slotProcessExited(KProcess*)
     m_outputQueue.clear();
 }
 
-void FestivalIntProc::slotReceivedStdout(KProcess*, char* buffer, int buflen)
+void FestivalIntProc::slotReceivedStdout(K3Process*, char* buffer, int buflen)
 {
     QString buf = QString::fromLatin1(buffer, buflen);
-    // kdDebug() << "FestivalIntProc::slotReceivedStdout: Received from Festival: " << buf << endl;
+    // kDebug() << "FestivalIntProc::slotReceivedStdout: Received from Festival: " << buf;
     bool promptSeen = (buf.contains("festival>") > 0);
     bool emitQueryVoicesFinished = false;
     QStringList voiceCodesList;
-    if (m_waitingQueryVoices)
+    if (m_waitingQueryVoices && m_outputQueue.isEmpty())
     {
         // Look for opening ( and closing ).
-        buf.simplifyWhiteSpace();
-        if (buf.left(1) == "(")
-        {
-            int rightParen = buf.find(')');
-            if (rightParen > 0)
+        buf.simplified();
+        if (buf.left(3) == "nil") {
+            emitQueryVoicesFinished = true;
+            m_waitingQueryVoices = false;
+        } else {
+            if (buf.left(1) == "(")
             {
-                m_waitingQueryVoices = false;
-                // Extract contents between parens.
-                buf = buf.mid(1, rightParen - 1);
-                // Space separated list.
-                voiceCodesList = QStringList::split(" ", buf, false);
-                emitQueryVoicesFinished = true;
+                int rightParen = buf.indexOf(')');
+                if (rightParen > 0)
+                {
+                    m_waitingQueryVoices = false;
+                    // Extract contents between parens.
+                    buf = buf.mid(1, rightParen - 1);
+                    // Space separated list.
+                    voiceCodesList = buf.split( " ", QString::SkipEmptyParts);
+                    emitQueryVoicesFinished = true;
+                }
             }
         }
     }
     if (promptSeen)
     {
-        // kdDebug() << "FestivalIntProc::slotReceivedStdout: Prompt seen" << endl;
+        // kDebug() << "FestivalIntProc::slotReceivedStdout: Prompt seen";
         m_ready = true;
         if (!sendIfReady())
         {
-            // kdDebug() << "FestivalIntProc::slotReceivedStdout: All output sent. " << endl;
+            // kDebug() << "FestivalIntProc::slotReceivedStdout: All output sent. ";
             pluginState prevState = m_state;
             if (m_state != psIdle) m_state = psFinished;
             if (prevState == psSaying)
             {
-                // kdDebug() << "FestivalIntProc::slotReceivedStdout: emitting sayFinished signal" << endl;
+                // kDebug() << "FestivalIntProc::slotReceivedStdout: emitting sayFinished signal";
                 emit sayFinished();
             } else
                 if (prevState == psSynthing)
@@ -513,12 +548,12 @@ void FestivalIntProc::slotReceivedStdout(KProcess*, char* buffer, int buflen)
                     {
                         m_waitingStop = false;
                         m_state = psIdle;
-                        // kdDebug() << "FestivalIntProc::slotReceivedStdout: emitting optimized stopped signal" << endl;
+                        // kDebug() << "FestivalIntProc::slotReceivedStdout: emitting optimized stopped signal";
                         emit stopped();
                     }
                     else
                     {
-                        // kdDebug() << "FestivalIntProc::slotReceivedStdout: emitting synthFinished signal" << endl;
+                        // kDebug() << "FestivalIntProc::slotReceivedStdout: emitting synthFinished signal";
                         emit synthFinished();
                     }
                 }
@@ -526,34 +561,35 @@ void FestivalIntProc::slotReceivedStdout(KProcess*, char* buffer, int buflen)
     }
     if (emitQueryVoicesFinished)
     {
-        // kdDebug() << "FestivalIntProc::slotReceivedStdout: emitting queryVoicesFinished" << endl;
+        // kDebug() << "FestivalIntProc::slotReceivedStdout: emitting queryVoicesFinished";
+        m_supportsSSML = (voiceCodesList.contains("rab_diphone")) ? ssYes : ssNo;
         emit queryVoicesFinished(voiceCodesList);
     }
 }
 
-void FestivalIntProc::slotReceivedStderr(KProcess*, char* buffer, int buflen)
+void FestivalIntProc::slotReceivedStderr(K3Process*, char* buffer, int buflen)
 {
     QString buf = QString::fromLatin1(buffer, buflen);
-    kdDebug() << "FestivalIntProc::slotReceivedStderr: Received error from Festival: " << buf << endl;
+    kDebug() << "FestivalIntProc::slotReceivedStderr: Received error from Festival: " << buf;
 }
 
-void FestivalIntProc::slotWroteStdin(KProcess* /*proc*/)
+void FestivalIntProc::slotWroteStdin(K3Process* /*proc*/)
 {
-    // kdDebug() << "FestivalIntProc::slotWroteStdin: Running" << endl;
+    // kDebug() << "FestivalIntProc::slotWroteStdin: Running";
     m_writingStdin = false;
     if (!sendIfReady())
     {
-        // kdDebug() << "FestivalIntProc::slotWroteStdin: all output sent" << endl;
+        // kDebug() << "FestivalIntProc::slotWroteStdin: all output sent";
         pluginState prevState = m_state;
         if (m_state != psIdle) m_state = psFinished;
         if (prevState == psSaying)
         {
-            // kdDebug() << "FestivalIntProc::slotWroteStdin: emitting sayFinished signal" << endl;
+            // kDebug() << "FestivalIntProc::slotWroteStdin: emitting sayFinished signal";
             emit sayFinished();
         } else
             if (prevState == psSynthing)
             {
-                // kdDebug() << "FestivalIntProc::slotWroteStdin: emitting synthFinished signal" << endl;
+                // kDebug() << "FestivalIntProc::slotWroteStdin: emitting synthFinished signal";
                 emit synthFinished();
             }
     }
@@ -584,7 +620,7 @@ void FestivalIntProc::ackFinished()
     if (m_state == psFinished)
     {
         m_state = psIdle;
-        m_synthFilename = QString::null;
+        m_synthFilename.clear();
     }
 }
 
@@ -618,6 +654,9 @@ bool FestivalIntProc::supportsSynth() { return true; }
 */
 QString FestivalIntProc::getSsmlXsltFilename()
 {
-    return KGlobal::dirs()->resourceDirs("data").last() + "kttsd/festivalint/xslt/SSMLtoSable.xsl";
+    if (m_supportsSSML == ssYes)
+        return KGlobal::dirs()->resourceDirs("data").last() + "kttsd/festivalint/xslt/SSMLtoSable.xsl";
+    else
+        return PlugInProc::getSsmlXsltFilename();
 }
 
